@@ -1054,6 +1054,7 @@ int ffiter(int n_cols,
             unsigned long  ulongnull;
             float  floatnull;
             double doublenull;
+	    LONGLONG longlongnull;
         } null;
     } colNulls;
 
@@ -1076,8 +1077,6 @@ int ffiter(int n_cols,
         return(*status = BAD_COL_NUM);  /* negative number of columns */
     }
 
-    col = calloc(n_cols, sizeof(colNulls) ); /* memory for the null values */
-
     /*------------------------------------------------------------*/
     /* Make sure column numbers and datatypes are in legal range  */
     /* and column numbers and datatypes are legal.                */ 
@@ -1103,14 +1102,15 @@ int ffiter(int n_cols,
             type != TSBYTE && type != TLOGICAL && type != TSTRING &&
             type != TSHORT && type != TINT     && type != TLONG && 
             type != TFLOAT && type != TDOUBLE  && type != TCOMPLEX &&
-            type != TULONG && type != TUSHORT  && type != TDBLCOMPLEX)
+            type != TULONG && type != TUSHORT  && type != TDBLCOMPLEX &&
+	    type != TLONGLONG )
         {
 	    if (type < 0) {
-	      sprintf(message,
+	      snprintf(message,FLEN_ERRMSG,
               "Variable length array not allowed for output column number %d (ffiter)",
                     jj + 1);
 	    } else {
-            sprintf(message,
+            snprintf(message,FLEN_ERRMSG,
                    "Illegal datatype for column number %d: %d  (ffiter)",
                     jj + 1, cols[jj].datatype);
 	    }
@@ -1127,11 +1127,11 @@ int ffiter(int n_cols,
 
         ffghdt(cols[jj].fptr, &jtype, status);  /* get HDU type */
 
-        if (hdutype == IMAGE_HDU)
+        if (hdutype == IMAGE_HDU) /* operating on FITS images */
         {
             if (jtype != IMAGE_HDU)
             {
-                sprintf(message,
+                snprintf(message,FLEN_ERRMSG,
                 "File %d not positioned to an image extension (ffiter)",
                     jj + 1);
                 return(*status = NOT_IMAGE);
@@ -1144,11 +1144,11 @@ int ffiter(int n_cols,
             tstatus = 0;
             ffgkys(cols[jj].fptr, "BUNIT", cols[jj].tunit, 0, &tstatus);
         }
-        else
+        else  /* operating on FITS tables */
         {
             if (jtype == IMAGE_HDU)
             {
-                sprintf(message,
+                snprintf(message,FLEN_ERRMSG,
                 "File %d not positioned to a table extension (ffiter)",
                     jj + 1);
                 return(*status = NOT_TABLE);
@@ -1160,7 +1160,7 @@ int ffiter(int n_cols,
                 if (ffgcno(cols[jj].fptr, CASEINSEN, cols[jj].colname,
                            &cols[jj].colnum, status) )
                 {
-                    sprintf(message,
+                    snprintf(message,FLEN_ERRMSG,
                       "Column '%s' not found for column number %d  (ffiter)",
                        cols[jj].colname, jj + 1);
                     ffpmsg(message);
@@ -1168,10 +1168,11 @@ int ffiter(int n_cols,
                 }
             }
 
+            /* check that the column number is valid */
             if (cols[jj].colnum < 1 || 
                 cols[jj].colnum > ((cols[jj].fptr)->Fptr)->tfield)
             {
-                sprintf(message,
+                snprintf(message,FLEN_ERRMSG,
                   "Column %d has illegal table position number: %d  (ffiter)",
                     jj + 1, cols[jj].colnum);
                 ffpmsg(message);
@@ -1201,7 +1202,7 @@ int ffiter(int n_cols,
             ffkeyn("TDISP", cols[jj].colnum, keyname, &tstatus);
             ffgkys(cols[jj].fptr, keyname, cols[jj].tdisp, 0, &tstatus);
         }
-    }
+    }  /* end of loop over all columns */
 
     /*-----------------------------------------------------------------*/
     /* use the first file to set the total number of values to process */
@@ -1273,6 +1274,7 @@ int ffiter(int n_cols,
             }
         }
 
+        /* divid n_optimum by the number of files that will be processed */
         n_optimum = n_optimum / nfiles;
         n_optimum = maxvalue(n_optimum, 1);
     }
@@ -1290,6 +1292,14 @@ int ffiter(int n_cols,
     /* and determine the null pixel value   */
     /*--------------------------------------*/
 
+    col = calloc(n_cols, sizeof(colNulls) ); /* memory for the null values */
+    if (!col)
+    {
+        ffpmsg("ffiter failed to allocate memory for null values");
+        *status = MEMORY_ALLOCATION;  /* memory allocation failed */
+        return(*status);
+    }
+
     for (jj = 0; jj < n_cols; jj++)
     {
         /* get image or column datatype and vector length */
@@ -1312,6 +1322,9 @@ int ffiter(int n_cols,
              case DOUBLE_IMG:
                  typecode = TDOUBLE;
                  break;
+             case LONGLONG_IMG:
+                 typecode = TLONGLONG;
+                 break;
             }
         }
         else
@@ -1328,7 +1341,7 @@ int ffiter(int n_cols,
 	       negative type code value. */
 
               if (cols[jj].iotype == OutputCol) {
- 	        sprintf(message,
+ 	        snprintf(message,FLEN_ERRMSG,
                 "Variable length array not allowed for output column number %d (ffiter)",
                     jj + 1);
                 ffpmsg(message);
@@ -1369,7 +1382,8 @@ int ffiter(int n_cols,
             cols[jj].repeat = 1;
 
             /* get the BLANK keyword value, if it exists */
-            if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+            if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+                || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
             {
                 tstatus = 0;
                 ffgkyj(cols[jj].fptr, "BLANK", &tnull, 0, &tstatus);
@@ -1397,7 +1411,8 @@ int ffiter(int n_cols,
             cols[jj].repeat = rept;
 
             /* get the TNULL keyword value, if it exists */
-            if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+            if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+                || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
             {
                 tstatus = 0;
                 if (hdutype == ASCII_TBL) /* TNULLn value is a string */
@@ -1457,7 +1472,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(char));
           col[jj].nullsize  = sizeof(char);  /* number of bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+              || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               tnull = minvalue(tnull, 255);
               tnull = maxvalue(tnull, 0);
@@ -1473,7 +1489,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(char));
           col[jj].nullsize  = sizeof(char);  /* number of bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+              || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               tnull = minvalue(tnull, 127);
               tnull = maxvalue(tnull, -128);
@@ -1489,7 +1506,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(short));
           col[jj].nullsize  = sizeof(short);  /* number of bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+              || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               tnull = minvalue(tnull, SHRT_MAX);
               tnull = maxvalue(tnull, SHRT_MIN);
@@ -1505,9 +1523,10 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(unsigned short));
           col[jj].nullsize  = sizeof(unsigned short);  /* bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+               || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
-              tnull = minvalue(tnull, USHRT_MAX);
+              tnull = minvalue(tnull, (long) USHRT_MAX);
               tnull = maxvalue(tnull, 0);  /* don't allow negative value */
               col[jj].null.ushortnull = (unsigned short) tnull;
           }
@@ -1521,7 +1540,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(sizeof(int), ntodo + 1);
           col[jj].nullsize  = sizeof(int);  /* number of bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+               || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               tnull = minvalue(tnull, INT_MAX);
               tnull = maxvalue(tnull, INT_MIN);
@@ -1537,7 +1557,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(unsigned int));
           col[jj].nullsize  = sizeof(unsigned int);  /* bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+               || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               tnull = minvalue(tnull, INT32_MAX);
               tnull = maxvalue(tnull, 0);
@@ -1545,7 +1566,7 @@ int ffiter(int n_cols,
           }
           else
           {
-              col[jj].null.intnull = UINT_MAX;  /* use maximum as null */
+              col[jj].null.uintnull = UINT_MAX;  /* use maximum as null */
           }
           break;
 
@@ -1553,7 +1574,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(long));
           col[jj].nullsize  = sizeof(long);  /* number of bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+               || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               col[jj].null.longnull = tnull;
           }
@@ -1567,7 +1589,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(unsigned long));
           col[jj].nullsize  = sizeof(unsigned long);  /* bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+               || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               if (tnull < 0)  /* can't use a negative null value */
                   col[jj].null.ulongnull = LONG_MAX;
@@ -1584,7 +1607,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(float));
           col[jj].nullsize  = sizeof(float);  /* number of bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+               || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               col[jj].null.floatnull = (float) tnull;
           }
@@ -1604,7 +1628,8 @@ int ffiter(int n_cols,
           cols[jj].array = calloc(ntodo + 1, sizeof(double));
           col[jj].nullsize  = sizeof(double);  /* number of bytes per value */
 
-          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG)
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG
+               || abs(typecode) == TINT || abs(typecode) == TLONGLONG)
           {
               col[jj].null.doublenull = (double) tnull;
           }
@@ -1668,8 +1693,23 @@ int ffiter(int n_cols,
           col[jj].null.charnull = 2;
           break;
 
+         case TLONGLONG:
+          cols[jj].array = calloc(ntodo + 1, sizeof(LONGLONG));
+          col[jj].nullsize  = sizeof(LONGLONG);  /* number of bytes per value */
+
+          if (abs(typecode) == TBYTE || abs(typecode) == TSHORT || abs(typecode) == TLONG ||
+	      abs(typecode) == TLONGLONG || abs(typecode) == TINT)
+          {
+              col[jj].null.longlongnull = tnull;
+          }
+          else
+          {
+              col[jj].null.longlongnull = LONGLONG_MIN;   /* use minimum as null */
+          }
+          break;
+
          default:
-          sprintf(message,
+          snprintf(message,FLEN_ERRMSG,
                   "Column %d datatype currently not supported: %d:  (ffiter)",
                    jj + 1, cols[jj].datatype);
           ffpmsg(message);
@@ -1892,7 +1932,8 @@ cleanup:
                 free(col[jj].null.stringnull); /* free the null string */
             }
         }
-        free(cols[jj].array); /* memory for the array of values from the col */
+        if (cols[jj].array)
+            free(cols[jj].array); /* memory for the array of values from the col */
     }
     free(col);   /* the structure containing the null values */
     return(*status);
