@@ -482,7 +482,7 @@ int ffpcluk(fitsfile *fptr,  /* I - FITS file pointer                       */
                 /* can't write to string column, so fall thru to default: */
 
             default:  /*  error trap  */
-                sprintf(message, 
+                snprintf(message,FLEN_ERRMSG, 
                      "Cannot write numbers to column %d which has format %s",
                       colnum,tform);
                 ffpmsg(message);
@@ -498,7 +498,7 @@ int ffpcluk(fitsfile *fptr,  /* I - FITS file pointer                       */
         /*-------------------------*/
         if (*status > 0)  /* test for error during previous write operation */
         {
-          sprintf(message,
+          snprintf(message,FLEN_ERRMSG,
           "Error writing elements %.0f thru %.0f of input data array (ffpcluk).",
               (double) (next+1), (double) (next+ntodo));
           ffpmsg(message);
